<?php
/*
Plugin Name: Wecreativez Woo Exit Popup Feedback
Plugin URI:  http://wecreativez.com/
Description: Woo Exit Popup Feedback will increase the visibility of your feedback form and encourage more form submissions. You can increase the visibility of your form by integrating your feedback form with a Woo Exit Popup Feedback.
Version:     1.0
Author:      20script
Author URI:  http://www.20script.ir/
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: wepf
Domain Path: /languages
*/


if ( ! class_exists( 'Wc_wepf' ) ) {

	class Wc_wepf {


		function __construct() {
			$this->version = 1.0;
			$this->plugin_setting = 'wepf_settings';
			$this->plugin_url = plugin_dir_url( __FILE__ );
			$this->plugin_path = plugin_dir_path( __FILE__ );
			register_activation_hook(__FILE__, array($this, 'plugin_activation_call'));
			add_action( 'wp_enqueue_scripts', array( $this, 'add_public_resources' ) );
			add_action( 'wp_head', array( $this, 'add_css_public_head' ) );
			add_action( 'wp_footer', array( $this, 'add_js_public_footer' ) );
			add_action( 'wp_footer', array( $this, 'add_public_template' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'add_admin_resources' ) );
			add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
			add_action( 'init', array( $this, 'save_plugin_settings' ) );
			add_action( 'init', array( $this, 'save_csv' ) );
			add_action( 'init', array( $this, 'delete_feedback_csv' ) );
		}

		function plugin_activation_call() {

			$options = [
				'interface_bg_color' => '#1d6887',
				'interface_text_color' => '#fff',
				'text_header_text' => 'Did you find what you were looking for?',
				'text_button_text' => 'Submit',
				'text_close_text' => 'I will do it later',
				'setting_display_on_mobile' => 1,
				'setting_popup_display_on_mobile_after' => 1,
				'setting_display_on_desktop' => 1,
				'setting_display_close_text' => 1,
				'setting_enable_rlt' => 'ltr',
				'setting_popup_display_after' => 1,
				'setting_popup_display_on_mobile_after' => 15,
				'setting_popup_display_after' => 7,
			];
			$options['feedback_questions'] = [
				'que1' => 'Yes. I am satisfied',
				'que2' => 'No. I didn’t find the product I was looking for',
				'que3' => 'No. You don’t deliver in my city',
				'que4' => 'No. I found your prices higher',
				'que5' => 'No. website is slow/difficult to navigate',
			];

			if ( ! add_option( $this->plugin_setting, $options ) );

		}
		function get_setting($option) {
			$setting = get_option($this->plugin_setting);
			return html_entity_decode(stripslashes($setting[$option]));
		}
		function get_question($que) {
			$question = get_option($this->plugin_setting);
			return html_entity_decode(stripslashes($question['feedback_questions'][$que]));
		}
		function add_public_resources() {
			wp_enqueue_style( 'wepf-public-style', $this->plugin_url.'public/css/wepf-public-style.css');
			wp_enqueue_script( 'wepf-public-script', $this->plugin_url.'public/js/wepf-public-script.js', NULL, false, true );
			wp_localize_script(
				'wepf-public-script', 
				'wepfObj', 
				array(
					'wepf_popup_display_after' => $this->get_setting('setting_popup_display_after'),
					'wepf_is_mobile' => (wp_is_mobile() == true) ? 1 : 0,
					'wepf_popup_display_mobile_seconds' =>  $this->get_setting('setting_popup_display_on_mobile_after'),
				)
			);
		}
		function add_css_public_head() { ?>
			<!-- style come from WeCreativez Exit Popup Feedback -->
			<style>
				#wepf * {
					direction: <?php echo $this->get_setting('setting_enable_rlt') ?>;
				}
				#wepf .wepf__container .wepf__header,
				#wepf-form button[type="submit"] {
					background-color: <?php echo $this->get_setting('interface_bg_color') ?>;
				}
				#wepf .wepf__container .wepf__header h3,
				#wepf-form button[type="submit"] {
					color: <?php echo $this->get_setting('interface_text_color') ?>;
				}
			</style>
			<!-- end style come from WeCreativez Exit Popup Feedback -->
		<?php }

		function add_public_template() {
			if ( wp_is_mobile() && $this->get_setting('setting_display_on_mobile') == 0 ) {
				return;
			}

			if ( ! wp_is_mobile() && $this->get_setting('setting_display_on_desktop') == 0 ) {
				return;
			}
			require_once $this->plugin_path.'public/templates/trigger-bar.php';
			require_once $this->plugin_path.'public/templates/template1.php';
		}

		function check_update() {

			$url = 'http://wecreativez.com/repository/codecanyon/woo-exit-popup-feedback/version.php';
			$response = wp_remote_post( $url, array(
			    'method'      => 'POST',
			    'timeout'     => 30,
			    'redirection' => 5,
			    'httpversion' => '1.0',
			    'blocking'    => true,
			    'headers'     => array(),
			    'body'        => array(
			        'current_version' => $this->version
			    ),
			    'cookies'     => array()
			    )
			);
			 
			if ( $response ) {
				 echo $response['body'];
			}
		}

		function add_admin_resources() {
			wp_enqueue_style( 'wepf-admin-style', $this->plugin_url.'admin/css/wepf-admin-style.css' );
			wp_enqueue_style('wp-color-picker');
			wp_enqueue_script('wepf-admin-script', $this->plugin_url . 'admin/js/wepf-admin-script.js', array('wp-color-picker'), false, true);
		}

		function add_admin_menu() {
			add_menu_page( 
				__('WC Exit Popup Feedback', 'wepf'), 
				__('WC Exit Popup Feedback', 'wepf'), 
				'manage_options', 
				'wecreativez-exit-popup-feedback', 
				array( $this, 'wc_admin_function'), 
				'dashicons-art', 
				NULL );
		}

		function wc_admin_function() {
			require_once $this->plugin_path.'admin/admin-page.php';
		}

		function save_plugin_settings() {

			if ( ! isset( $_POST['wepf_admin_form_submit'] ) ) return;

			$new_options = [
				'interface_bg_color' => $_POST['wepf_input']['interface_bg_color'],
				'interface_text_color' => $_POST['wepf_input']['interface_text_color'],
				'text_header_text' => htmlentities($_POST['wepf_input']['text_header_text']),
				'text_button_text' => htmlentities($_POST['wepf_input']['text_button_text']),
				'text_close_text' => htmlentities($_POST['wepf_input']['text_close_text']),
				'setting_display_on_mobile' => $_POST['wepf_input']['setting_display_on_mobile'],
				'setting_popup_display_on_mobile_after' => $_POST['wepf_input']['setting_popup_display_on_mobile_after'],
				'setting_display_on_desktop' => $_POST['wepf_input']['setting_display_on_desktop'],
				'setting_display_close_text' => $_POST['wepf_input']['setting_display_close_text'],
				'setting_enable_rlt' => $_POST['wepf_input']['setting_enable_rlt'],
				'setting_popup_display_after' => $_POST['wepf_input']['setting_popup_display_after']
			];
			$new_options['feedback_questions'] = [
				'que1' => htmlentities($_POST['wepf_input']['feedback_questions']['que1']),
				'que2' => htmlentities($_POST['wepf_input']['feedback_questions']['que2']),
				'que3' => htmlentities($_POST['wepf_input']['feedback_questions']['que3']),
				'que4' => htmlentities($_POST['wepf_input']['feedback_questions']['que4']),
				'que5' => htmlentities($_POST['wepf_input']['feedback_questions']['que5']),
			];

			update_option( $this->plugin_setting, $new_options );

		}

		function feedback_csv_folder() {
			return WP_CONTENT_DIR.'/uploads/wepf-csv';
		}

		function feedback_csv_path() {
			return WP_CONTENT_DIR.'/uploads/wepf-csv/exit-popup-feedback.csv';
		}

		function feedback_csv_url() {
			return content_url().'/uploads/wepf-csv/exit-popup-feedback.csv';
		}

		function delete_feedback_csv() {

			if ( ! isset($_GET['wepf_delete_csv'])) return;

			unlink($this->feedback_csv_path());
		}

		function save_csv() {

			global $current_user;

			if ( ! isset( $_POST['wepf_public_form_submit'] ) ) return;

			wp_mkdir_p( $this->feedback_csv_folder() );


			if ( ! file_exists($this->feedback_csv_path()) ) {
				$head = "Date, Name, Feedback";
				file_put_contents($this->feedback_csv_path(), $head . PHP_EOL, FILE_APPEND);
			}

			$current_date = current_time('F j Y  g:i a');

			if (!empty($current_user->display_name)) {
				$user_name = $current_user->display_name;
			} else {
				$user_name = 'Guest';
			}

			$wepf_feedback = stripslashes($_POST['wepf_input_feedback']);
			
			$line = "$current_date, $user_name, $wepf_feedback";
			file_put_contents($this->feedback_csv_path(), $line . PHP_EOL, FILE_APPEND);

		}

	} 


	new Wc_wepf;

} 